summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qmenuitem_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qmenuitem_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qmenuitem_imp.cpp50
1 files changed, 25 insertions, 25 deletions
diff --git a/kjsembed/qtbindings/qmenuitem_imp.cpp b/kjsembed/qtbindings/qmenuitem_imp.cpp
index 75118e4e..f65fa910 100644
--- a/kjsembed/qtbindings/qmenuitem_imp.cpp
+++ b/kjsembed/qtbindings/qmenuitem_imp.cpp
@@ -23,12 +23,12 @@
*/
namespace KJSEmbed {
-TTQMenuItemImp::TQMenuItemImp( KJS::ExecState *exec, int mid, bool constructor )
+TQMenuItemImp::TQMenuItemImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-TTQMenuItemImp::~TQMenuItemImp()
+TQMenuItemImp::~TQMenuItemImp()
{
}
@@ -43,7 +43,7 @@ void TQMenuItemImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object
};
int idx = 0;
- TTQCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -91,24 +91,24 @@ void TQMenuItemImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a TTQMenuItem pointer from an Object.
*/
-TTQMenuItem *TQMenuItemImp::toTQMenuItem( KJS::Object &self )
+TQMenuItem *TQMenuItemImp::toTQMenuItem( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TTQObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TTQMenuItem *>( obj );
+ return dynamic_cast<TQMenuItem *>( obj );
}
- if( !JSProxy::checkType(self, JSProxy::ObjectProxy, "TTQMenuItem") ) {
- TTQObject *obj = JSProxy::toObjectProxy( self.imp() )->object();
- return dynamic_cast<TTQMenuItem *>( obj );
+ if( !JSProxy::checkType(self, JSProxy::ObjectProxy, "TQMenuItem") ) {
+ TQObject *obj = JSProxy::toObjectProxy( self.imp() )->object();
+ return dynamic_cast<TQMenuItem *>( obj );
}
- if( !JSProxy::checkType(self, JSProxy::OpaqueProxy, "TTQMenuItem") ) {
- return JSProxy::toOpaqueProxy( self.imp() )->toNative<TTQMenuItem>();
+ if( !JSProxy::checkType(self, JSProxy::OpaqueProxy, "TQMenuItem") ) {
+ return JSProxy::toOpaqueProxy( self.imp() )->toNative<TQMenuItem>();
}
return 0;
@@ -129,7 +129,7 @@ KJS::Object TQMenuItemImp::construct( KJS::ExecState *exec, const KJS::List &arg
break;
}
- TTQString msg = i18n("TQMenuItemCons has no constructor with id '%1'").arg(id);
+ TQString msg = i18n("TQMenuItemCons has no constructor with id '%1'").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -138,9 +138,9 @@ KJS::Object TQMenuItemImp::TQMenuItem_1( KJS::ExecState *exec, const KJS::List &
{
- // We should now create an instance of the TTQMenuItem object
+ // We should now create an instance of the TQMenuItem object
- TTQMenuItem *ret = new TTQMenuItem(
+ TQMenuItem *ret = new TQMenuItem(
);
return KJS::Object();
@@ -236,7 +236,7 @@ KJS::Value TQMenuItemImp::call( KJS::ExecState *exec, KJS::Object &self, const K
break;
}
- TTQString msg = i18n( "TQMenuItemImp has no method with id '%1'" ).arg( id );
+ TQString msg = i18n( "TQMenuItemImp has no method with id '%1'" ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -254,14 +254,14 @@ KJS::Value TQMenuItemImp::iconSet_4( KJS::ExecState *exec, KJS::Object &obj, con
{
instance->iconSet( );
- return KJS::Value(); // Returns 'TTQIconSet *'
+ return KJS::Value(); // Returns 'TQIconSet *'
}
KJS::Value TQMenuItemImp::text_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString ret;
+ TQString ret;
ret = instance->text( );
return KJS::String( ret );
@@ -270,7 +270,7 @@ KJS::Value TQMenuItemImp::text_5( KJS::ExecState *exec, KJS::Object &obj, const
KJS::Value TQMenuItemImp::whatsThis_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString ret;
+ TQString ret;
ret = instance->whatsThis( );
return KJS::String( ret );
@@ -287,7 +287,7 @@ KJS::Value TQMenuItemImp::popup_8( KJS::ExecState *exec, KJS::Object &obj, const
{
instance->popup( );
- return KJS::Value(); // Returns 'TTQPopupMenu *'
+ return KJS::Value(); // Returns 'TQPopupMenu *'
}
@@ -295,7 +295,7 @@ KJS::Value TQMenuItemImp::widget_9( KJS::ExecState *exec, KJS::Object &obj, cons
{
instance->widget( );
- return KJS::Value(); // Returns 'TTQWidget *'
+ return KJS::Value(); // Returns 'TQWidget *'
}
@@ -303,7 +303,7 @@ KJS::Value TQMenuItemImp::custom_10( KJS::ExecState *exec, KJS::Object &obj, con
{
instance->custom( );
- return KJS::Value(); // Returns 'TTQCustomMenuItem *'
+ return KJS::Value(); // Returns 'TQCustomMenuItem *'
}
@@ -318,7 +318,7 @@ KJS::Value TQMenuItemImp::signal_12( KJS::ExecState *exec, KJS::Object &obj, con
{
instance->signal( );
- return KJS::Value(); // Returns 'TTQSignal *'
+ return KJS::Value(); // Returns 'TQSignal *'
}
@@ -379,7 +379,7 @@ KJS::Value TQMenuItemImp::isEnabledAndVisible_18( KJS::ExecState *exec, KJS::Obj
KJS::Value TQMenuItemImp::setText_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = extractTQString(exec, args, 0);
+ TQString arg0 = extractTQString(exec, args, 0);
instance->setText(
arg0 );
@@ -412,7 +412,7 @@ KJS::Value TQMenuItemImp::setVisible_21( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQMenuItemImp::setWhatsThis_22( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = extractTQString(exec, args, 0);
+ TQString arg0 = extractTQString(exec, args, 0);
instance->setWhatsThis(
arg0 );
@@ -91,24 +91,24 @@ void TQMenuItemImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TTQMenuItem pointer from an Object.
+ * Extract a TQMenuItem pointer from an Object.
*/